@@ -132,7 +132,7 @@ function(x, hide.i, digits, digits.ratio, type, varname, hide.i.no, digits.p, sd
       if (sd.type==1)
         ans<-cbind(apply(nn,1,function(y) paste(y[1]," (",y[2],")",sep="")))
       else
-        ans<-cbind(apply(nn,1,function(y) paste(y[1],integerToAscii(177),y[2],sep="")))        
+        ans<-cbind(apply(nn,1,function(y) paste(y[1],intToUtf8(0xAFL),y[2],sep="")))        
     } else {
       if (q.type[1]==1){
         if (q.type[2]==1)
