@@ -1,4 +1,5 @@
 "[.createTable"<-function(x,i,...){
+  class.orig<-class(x)
   if (inherits(x,"rbind.createTable"))
     stop("x cannot be of class rbind.createTable")
   cc<-x$call
@@ -9,8 +10,10 @@
   hide<-paste("c(",paste(hide,collapse=","),")")
   digits<-paste("c(",paste(digits,collapse=","),")")  
   digits.ratio<-paste("c(",paste(digits.ratio,collapse=","),")")  
-  assign(".xxx",attr(x,"x")[[1]][i],envir=.GlobalEnv)
-  eval(parse(text=paste("update(x,x=.xxx,hide=",hide,",digits=",digits,")",sep="")))
+  obj.i<-attr(x,"x")[[1]][i]
+  ans<-eval(parse(text=paste("update(x,x=obj.i,hide=",hide,",digits=",digits,")",sep="")))
+  class(ans)<-class.orig
+  ans
 }
 
 
